==> theia-0.1.1-py3-none-any.whl: theia/aws/network/vpc.py <==
import pulumi

from pulumi_aws import ec2
from pulumi.output import Output

from typing import Optional, Mapping, List
from pydantic.dataclasses import dataclass, ConfigDict

from theia import ResourceOptions
from theia.registry import StackRegistry
from theia.utils.logger import Logger
from theia.definitions import THEIA_VERSION


logger = Logger("vpc")


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class VpcSettings:
    ipv6_cidr: Optional[str | Output[str]] = None
    enable_dns_hostnames: Optional[bool] = False
    enable_dns_support: Optional[bool] = True
    enable_network_address_usage_metrics: Optional[bool] = False
    secondary_cidr: Optional[str | Output[str]] = None


@dataclass
class VpcResult:
    id: str
    arn: str
    cidr_blocks: List[str]
    tenancy: str
    ipv6_cidr_block: str
    ipv6_association_id: str
    main_route_table_id: str


class Vpc:
    def __new__(
        cls,
        resource_name: str,
        ipv4_cidr: str,
        tenancy: str = "default",
        tags: Optional[Mapping[str, str]] = None,
        settings: Optional[VpcSettings] = VpcSettings(),
        opts: Optional[ResourceOptions] = None,
    ) -> ec2.Vpc:
        merged_tags = THEIA_VERSION
        name = {"Name": resource_name}
        if tags:
            merged_tags = {**tags, **name, **merged_tags}

        vpc_args = ec2.VpcArgs(
            ipv6_cidr_block=settings.ipv6_cidr,
            enable_dns_hostnames=settings.enable_dns_hostnames,
            enable_dns_support=settings.enable_dns_support,
            enable_network_address_usage_metrics=settings.enable_network_address_usage_metrics,
            tags=merged_tags,
            instance_tenancy=tenancy,
            cidr_block=ipv4_cidr,
        )

        logger.info(f"creating vpc resource {resource_name}")
        vpc = ec2.Vpc(resource_name, args=vpc_args, opts=opts)

        export_values = {"arn": vpc.arn, "id": vpc.id, "cidr": vpc.cidr_block}
        if settings.secondary_cidr:
            cls.secondary_cidr = ec2.VpcIpv4CidrBlockAssociation(
                f"{resource_name}-secondary_cidr",
                opts=ResourceOptions(parent=vpc, depends_on=[vpc]),
                vpc_id=vpc.id,
                cidr_block=settings.secondary_cidr,
            )
            export_values["secondary_cidr"] = cls.secondary_cidr.id

        pulumi.export(f"vpc---{resource_name}", export_values)

        return vpc

    @staticmethod
    def fetch(id: str) -> VpcResult:
        try:
            vpc = ec2.get_vpc(id=id)
        except Exception:
            logger.critical(f"vpc id {id} not found", exc_info=True)
            raise Exception(f"vpc id {id} not found")

        vpc_result = VpcResult(
            id=vpc.id,
            arn=vpc.arn,
            cidr_blocks=[cidr["cidr_block"] for cidr in vpc.cidr_block_associations],
            tenancy=vpc.instance_tenancy,
            ipv6_cidr_block=vpc.ipv6_cidr_block,
            ipv6_association_id=vpc.ipv6_association_id,
            main_route_table_id=vpc.main_route_table_id,
        )

        return vpc_result

    @staticmethod
    def import_(stack: str, resource_name: str) -> ec2.Vpc:
        stack_ref = StackRegistry.get(stack_name=stack)
        vpc = stack_ref.get_output(name=f"vpc---{resource_name}")
        return ec2.Vpc.get(resource_name=resource_name, id=vpc["id"])

==> theia-0.1.2-py3-none-any.whl: theia/aws/network/vpc.py <==
import pulumi

from pulumi_aws import ec2
from pulumi.output import Output

from typing import Optional, Mapping, List
from pydantic.dataclasses import dataclass, ConfigDict

from theia import ResourceOptions
from theia.utils.logger import Logger
from theia.definitions import THEIA_VERSION
from theia.registry import StackRegistry, GlobalTags


logger = Logger("vpc")


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class VpcSettings:
    ipv6_cidr: Optional[str | Output[str]] = None
    enable_dns_hostnames: Optional[bool] = False
    enable_dns_support: Optional[bool] = True
    enable_network_address_usage_metrics: Optional[bool] = False
    secondary_cidr: Optional[str | Output[str]] = None


@dataclass
class VpcResult:
    id: str
    arn: str
    cidr_blocks: List[str]
    tenancy: str
    ipv6_cidr_block: str
    ipv6_association_id: str
    main_route_table_id: str


class Vpc:
    def __new__(
        cls,
        resource_name: str,
        ipv4_cidr: str,
        tenancy: str = "default",
        tags: Optional[Mapping[str, str]] = None,
        settings: Optional[VpcSettings] = VpcSettings(),
        opts: Optional[ResourceOptions] = None,
    ) -> ec2.Vpc:
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        vpc_args = ec2.VpcArgs(
            ipv6_cidr_block=settings.ipv6_cidr,
            enable_dns_hostnames=settings.enable_dns_hostnames,
            enable_dns_support=settings.enable_dns_support,
            enable_network_address_usage_metrics=settings.enable_network_address_usage_metrics,
            tags=merged_tags,
            instance_tenancy=tenancy,
            cidr_block=ipv4_cidr,
        )

        vpc = ec2.Vpc(resource_name, args=vpc_args, opts=opts)

        export_values = {"arn": vpc.arn, "id": vpc.id, "cidr": vpc.cidr_block}
        if settings.secondary_cidr:
            cls.secondary_cidr = ec2.VpcIpv4CidrBlockAssociation(
                f"{resource_name}-secondary_cidr",
                opts=ResourceOptions(parent=vpc, depends_on=[vpc]),
                vpc_id=vpc.id,
                cidr_block=settings.secondary_cidr,
            )
            export_values["secondary_cidr"] = cls.secondary_cidr.id

        pulumi.export(f"vpc---{resource_name}", export_values)

        return vpc

    @staticmethod
    def fetch(id: str) -> VpcResult:
        try:
            vpc = ec2.get_vpc(id=id)
        except Exception:
            logger.critical(f"vpc id {id} not found", exc_info=True)
            raise Exception(f"vpc id {id} not found")

        vpc_result = VpcResult(
            id=vpc.id,
            arn=vpc.arn,
            cidr_blocks=[cidr["cidr_block"] for cidr in vpc.cidr_block_associations],
            tenancy=vpc.instance_tenancy,
            ipv6_cidr_block=vpc.ipv6_cidr_block,
            ipv6_association_id=vpc.ipv6_association_id,
            main_route_table_id=vpc.main_route_table_id,
        )

        return vpc_result

    @staticmethod
    def import_(stack: str, resource_name: str) -> ec2.Vpc:
        stack_ref = StackRegistry.get(stack_name=stack)
        vpc = stack_ref.get_output(name=f"vpc---{resource_name}")
        return ec2.Vpc.get(resource_name=resource_name, id=vpc["id"])
